@@ -22,17 +22,34 @@ def get_callback_name():
 
 @register.inclusion_tag("allcaptcha/challenge.html")
 def render_challenge(
-    challenge_type="visible", text="submit", js_callback=settings.PROVIDER_JS_CALLBACK
+    challenge_type="visible",
+    text="submit",
+    js_callback=None,
+    theme=None,
+    size=None,
 ) -> dict:
     if challenge_type == "visible" and (
         settings.PROVIDER == settings.RECAPTCHA_PROVIDER_NAME
         and settings.RECAPTCHA_VERSION == 3
     ):
         raise ValueError(_("Recaptcha V3 can't be visible."))
+
+    # Set these here because tests aren't passing with default arguments.
+    if js_callback is None:
+        js_callback = settings.PROVIDER_JS_CALLBACK
+
+    if theme is None:
+        theme = settings.CHALLENGE_THEME
+
+    if size is None:
+        size = settings.CHALLENGE_SIZE
+
     ctx = {
         "challenge_type": challenge_type,
         "callback": js_callback,
         "text": text,
+        "theme": theme,
+        "size": size,
     }
     if (
         settings.PROVIDER == settings.HCAPTCHA_PROVIDER_NAME
